pub struct ServiceInstall {
pub exe: PathBuf,
pub unit_path: PathBuf,
pub env_path: PathBuf,
pub listen: String,
pub health_url: String,
pub key_credential: Option<PathBuf>,
pub notes: Vec<String>,
}Fields
exe: PathBufunit_path: PathBufenv_path: PathBuflisten: Stringhealth_url: Stringkey_credential: Option<PathBuf>The daemon’s secrets key as an encrypted systemd credential, when this systemd can make one.
notes: Vec<String>Things the user should know, one sentence each (linger, version pinning).