pub struct ProxyOptions {
pub isb: String,
pub url: Option<String>,
pub token_file: Option<String>,
pub keys_of: Option<String>,
pub identity: Option<String>,
pub known_hosts: String,
}Expand description
How the blocks reach isb ssh-proxy.
Fields
isb: StringThe isb binary.
url: Option<String>--url for a remote daemon; none for the local socket.
token_file: Option<String>--token-file, when the token is in a file rather than ISB_TOKEN.
keys_of: Option<String>--as: whose keys, for a caller with no isb account (the socket).
identity: Option<String>IdentityFile (and IdentitiesOnly yes).
known_hosts: StringTrait Implementations
Sourceimpl Clone for ProxyOptions
impl Clone for ProxyOptions
Sourceimpl Debug for ProxyOptions
impl Debug for ProxyOptions
Sourceimpl Default for ProxyOptions
impl Default for ProxyOptions
impl Eq for ProxyOptions
Sourceimpl PartialEq for ProxyOptions
impl PartialEq for ProxyOptions
impl StructuralPartialEq for ProxyOptions