pub struct Tailnet { /* private fields */ }Expand description
The check isb serve --superadmin-tailnet runs on every TCP request.
Implementations
Sourceimpl Tailnet
impl Tailnet
pub fn new(allow: AllowList, fetch: WhoisFetcher, hosts: Vec<String>) -> Tailnet
pub fn allow(&self) -> &AllowList
pub fn hosts(&self) -> &[String]
Sourcepub fn identify(&self, req: &Request) -> Option<Whois>
pub fn identify(&self, req: &Request) -> Option<Whois>
The tailnet identity behind req: a TCP peer on a tailnet address,
a Host naming this server, and a whois answer. Who it is allowed
to be is the caller’s question (the superadmin allow list, an org’s
agent identities).
Sourcepub fn superadmin(&self, req: &Request) -> Option<Whois>
pub fn superadmin(&self, req: &Request) -> Option<Whois>
The tailnet identity behind req when it is on the superadmin
allow list.