AddOptions

Struct AddOptions 

pub struct AddOptions {
    pub name: String,
    pub ssh: String,
    pub ssh_port: u16,
    pub key: PathBuf,
    pub address: Option<String>,
    pub agent_port: u16,
    pub allow_from: Vec<String>,
    pub isb_binary: Option<PathBuf>,
    pub version: Option<String>,
    pub self_binary: bool,
    pub public_ingress: bool,
}
What isb server add was given.

Fields

name: Stringssh: String

user@host; the user is root or has passwordless sudo.

ssh_port: u16key: PathBufaddress: Option<String>

What the control plane dials, if not the SSH host.

agent_port: u16allow_from: Vec<String>

Firewall the box to SSH plus the agent port from these (ufw).

isb_binary: Option<PathBuf>

A Linux isb binary to install; default the release of this version.

version: Option<String>self_binary: bool

Install this control plane’s own executable (it must be a Linux build for the box’s architecture).

public_ingress: bool

Serve the box’s orgs’ domains on its own 80 and 443 (isb host setup --public-ingress, the agent’s --ingress-http/https).