boot

Function boot 

pub fn boot(
    client: &Client,
    org: &OrgId,
    size: &VmSize,
    p: &Provision,
) -> Result<Booted>
Make (or find) the VM for org, start it and wait until it runs commands and has an address. Idempotent: an existing VM of this org is reused; an instance of that name that is not one is refused.